@@ -242,6 +242,10 @@ class FeedManager(gobject.GObject):
         for feed_data in feed_data_list:
             updated_feed_data = ReSiStanceFeedDict(feedparser.parse(feed_data.href))
 
+            # In case of network failure
+            if updated_feed_data == None or updated_feed_data.entries == None:
+                continue
+
             updated_feed_date = updated_feed_data.feed.get('updated_parsed') or \
                 updated_feed_data.entries[0].get('updated_parsed')
             feed_date = feed_data.feed.get('updated_parsed') or \
@@ -252,7 +256,7 @@ class FeedManager(gobject.GObject):
                 old_feed_entries = feed_data.entries[:]
                 for entry in updated_feed_data.entries:
                     if entry in old_feed_entries:
-                        updated_feed_data.remove(entry)
+                        updated_feed_data.entries.remove(entry)
                 feed_data.update(updated_feed_data)
                 feed_data.entries += old_feed_entries
 
