@@ -282,20 +282,21 @@ class FeedsWindow(hildon.StackableWindow):
         self.edit_toolbar = hildon.EditToolbar()
         self.edit_toolbar.connect('arrow-clicked', self._restore_normal_mode)
 
-        align = gtk.Alignment(0, 0, 1, 1)
-        align.set_padding(4, 0 , 16, 16)
+        self.align = gtk.Alignment(0, 0, 1, 1)
+        self.align.set_padding(4, 0 , 16, 16)
 
         pannable = hildon.PannableArea()
         pannable.add (self.view)
         pannable.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
         pannable.show()
 
-        align.add(pannable)
-        self.add(align)
-        align.show()
+        self.align.add(pannable)
+        self.add(self.align)
+        self.align.show()
 
         self._create_menu()
         self.set_title(app_name)
+        self.connect('configure-event', self._on_configuration_changed)
         self.connect('delete-event', self._on_exit)
         hildon.Program.get_instance().add_window(self)
 
@@ -337,6 +338,14 @@ class FeedsWindow(hildon.StackableWindow):
         unread_count = len([entry for entry in feed_data.entries if entry.read == False])
         self.view.get_model().set(feed_iter, self.view.FEEDS_READ_COLUMN, unread_count)
 
+    def _on_configuration_changed(self, window, event):
+        # Change alignment padding. We don't want padding in portrait
+        # Need to save space
+        if event.width > event.height:
+            self.align.set_padding(4, 0 , 16, 16)
+        else:
+            self.align.set_padding(4, 0 , 4, 4)
+
     def _on_exit(self, window, event):
         # Save the feeds status
         manager.save(self._on_feed_data_saved)
@@ -457,6 +466,12 @@ class FeedsWindow(hildon.StackableWindow):
     def _all_feeds_updated_cb(self, data):
         hildon.hildon_gtk_window_set_progress_indicator(self, False)
 
+        # TODO: Update counters
+        store = self.view.get_model()
+        for row in store:
+            unread_count = len([entry for entry in row[self.view.FEEDS_DATA_COLUMN].entries if entry.read == False])
+            row[self.view.FEEDS_READ_COLUMN] = unread_count
+
     def _new_feed_response_cb(self, dialog, response):
 
         if response == gtk.RESPONSE_ACCEPT:
@@ -523,10 +538,10 @@ class FeedsWindow(hildon.StackableWindow):
             store = self.view.get_model()
 
             for feed_data in feed_data_list:
-                iter = store.append()
+                feed_iter = store.append()
                 pixbuf = manager.get_favicon(feed_data.feed.link or feed_data.href)
                 unread_count = len([entry for entry in feed_data.entries if entry.read == False])
-                store.set(iter, self.view.FEEDS_ICON_COLUMN, pixbuf,
+                store.set(feed_iter, self.view.FEEDS_ICON_COLUMN, pixbuf,
                           self.view.FEEDS_NAME_COLUMN, self.view.get_feed_title_markup(feed_data),
                           self.view.FEEDS_DATA_COLUMN, feed_data,
                           self.view.FEEDS_READ_COLUMN, unread_count)
@@ -604,6 +619,10 @@ class EntriesView(hildon.GtkTreeView):
 
     def get_visual_entry_date(self, entry):
 
+        if entry.has_key('updated_parsed') == False:
+            return '<span size="xx-small">%s</span>' % \
+                entry.updated
+
         now = time.localtime()
 
         # Today
@@ -645,20 +664,22 @@ class EntriesWindow(hildon.StackableWindow):
             model.set(entry_iter, 1, entry.title, 2, entry,
                       3, self.view.get_visual_entry_date(entry))
 
-        align = gtk.Alignment(0, 0, 1, 1)
-        align.set_padding(4, 0 , 16, 16)
+        self.align = gtk.Alignment(0, 0, 1, 1)
+        self.align.set_padding(4, 0 , 16, 16)
 
         pannable = hildon.PannableArea()
         pannable.add (self.view)
         pannable.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
         pannable.show()
 
-        align.add(pannable)
-        self.add(align)
-        align.show()
+        self.align.add(pannable)
+        self.add(self.align)
+        self.align.show()
 
         self._create_menu()
 
+        self.connect('configure-event', self._on_configuration_changed)
+
     def _create_menu(self):
         menu = hildon.AppMenu()
 
@@ -708,6 +729,14 @@ class EntriesWindow(hildon.StackableWindow):
 
         return
 
+    def _on_configuration_changed(self, window, event):
+        # Change alignment padding. We don't want padding in portrait
+        # Need to save space
+        if event.width > event.height:
+            self.align.set_padding(4, 0 , 16, 16)
+        else:
+            self.align.set_padding(4, 0 , 4, 4)
+
 class ItemWindowHeader(gtk.HBox):
 
     def __init__(self, homogeneous, spacing, item):
@@ -720,15 +749,11 @@ class ItemWindowHeader(gtk.HBox):
         navigation_hbox = gtk.HBox(False, 0)
 
         # Author and URL
-        self.author = gtk.Label('')
-        self.author.set_alignment(0,0.5)
-        self.author.set_ellipsize(pango.ELLIPSIZE_END)
-        # self.url = gtk.LinkButton('', _('View in Browser'))
-        # self.url.set_alignment(0,0.5)
-        header_vbox.pack_start(self.author, True, False)
-#        header_vbox.pack_start(self.url, True, False)
-        self.author.show()
-#        self.url.show()
+        self.title = gtk.Label('')
+        self.title.set_alignment(0,0.5)
+        self.title.set_ellipsize(pango.ELLIPSIZE_END)
+        header_vbox.pack_start(self.title, True, False)
+        self.title.show()
         self.set_item(item)
         header_vbox.show()
 
@@ -765,7 +790,7 @@ class ItemWindowHeader(gtk.HBox):
         # Mark item as read
         item['read'] = True
 
-        self.author.set_text(get_author_from_item(item))
+        self.title.set_markup('<span size="small">' + unescape(item.title) + '</span>')
         #self.url.set_uri(item.link)
 
 class ItemWindow(hildon.StackableWindow):
@@ -787,18 +812,22 @@ class ItemWindow(hildon.StackableWindow):
 
         # HTML renderer
         self.view = webkit.WebView()
+        self.view.set_full_content_zoom(True)
+
+        # Disable text selection
+        self.view.connect("motion-notify-event", lambda w, ev: True)
+
+        # Set some settings
         wbk_settings = self.view.get_settings()
-        # TODO: read this from settings
         wbk_settings.set_property('default_font_size', settings.default_font_size)
         wbk_settings.set_property('auto-load-images', settings.auto_load_images)
         wbk_settings.set_property('auto-shrink-images', True)
-        self.set_item(item)
 
         # Pannable for showing content
-        pannable = hildon.PannableArea()
-        pannable.add(self.view)
-        pannable.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
-        pannable.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
+        self.pannable = hildon.PannableArea()
+        self.pannable.add(self.view)
+        self.pannable.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
+        self.pannable.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
         self.view.show()
 
         # Header Alignment
@@ -809,14 +838,57 @@ class ItemWindow(hildon.StackableWindow):
 
         vbox = gtk.VBox(False, 8)
         vbox.pack_start(header_align, False, False)
-        vbox.pack_start(pannable, True, True)
+        vbox.pack_start(self.pannable, True, True)
         self.item_window_header.show()
-        pannable.show()
+        self.pannable.show()
 
         self.add(vbox)
         vbox.show()
 
         self._create_menu()
+        self._create_toolbar()
+
+        self.connect('configure-event', self._on_configuration_changed)
+        self.set_item(item)
+
+    def _on_configuration_changed(self, window, event):
+
+        # Show toolbar in portrait mode. Show header in landscape mode
+        if event.width > event.height:
+            self.pannable.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
+            self.item_window_header.show_all()
+            self.toolbar.hide_all()
+        else:
+            self.pannable.set_property("mov-mode", hildon.MOVEMENT_MODE_VERT)
+            self.item_window_header.button_up.hide()
+            self.item_window_header.button_down.hide()
+            self.toolbar.show_all()
+
+    def _create_toolbar(self):
+
+        self.toolbar = gtk.Toolbar()
+        button_prev_img = gtk.Image()
+        button_prev_img.set_from_icon_name(constants.ICON_UP_NAME,
+                                           gtk.HILDON_SIZE_FINGER_HEIGHT)
+        button_prev = gtk.ToolButton(button_prev_img, None)
+
+        button_next_img = gtk.Image()
+        button_next_img.set_from_icon_name(constants.ICON_DOWN_NAME,
+                                           gtk.HILDON_SIZE_FINGER_HEIGHT)
+        button_next = gtk.ToolButton(button_next_img, None)
+
+        button_prev.set_expand(True)
+        button_next.set_expand(True)
+        button_prev.set_homogeneous(True)
+        button_next.set_homogeneous(True)
+
+        self.toolbar.insert (button_prev, -1)
+        self.toolbar.insert (button_next, -1)
+
+        button_prev.connect("clicked", self._up_button_clicked)
+        button_next.connect("clicked", self._down_button_clicked)
+
+        self.add_toolbar(self.toolbar)
 
     def _on_request_url(self, object, url, stream):
         if (url.lower().startswith("http")):
@@ -909,7 +981,7 @@ class ItemWindow(hildon.StackableWindow):
 
     def set_item(self, item):
 
-        self.set_title(unescape(item.title))
+        self.set_title(get_author_from_item(item))
 
         # Set item in header
         self.item_window_header.set_item(item)
@@ -933,12 +1005,18 @@ class ItemWindow(hildon.StackableWindow):
         self.view.load_string(body, content_type, self.feed_data.encoding, '')
 
         # Update button sensitiviness
+        toolbar_button_list = self.toolbar.get_children()
         path = self.model.get_path(self.model_iter)
         position = path[-1]
         if position == 0:
             self.item_window_header.button_up.set_sensitive(False)
+            toolbar_button_list[0].set_sensitive(False)
         elif position == len(self.model) - 1:
             self.item_window_header.button_down.set_sensitive(False)
+            toolbar_button_list[1].set_sensitive(False)
         else:
             self.item_window_header.button_up.set_sensitive(True)
             self.item_window_header.button_down.set_sensitive(True)
+            toolbar_button_list[0].set_sensitive(True)
+            toolbar_button_list[1].set_sensitive(True)
+
